@@ -27,7 +27,7 @@ email                : marco.hugentobler at sourcepole dot com
 #include "qgswkbptr.h"
 
 #ifndef SIP_RUN
-#include "json_fwd.hpp"
+#include <nlohmann/json_fwd.hpp>
 using namespace nlohmann;
 #endif
 
@@ -65,7 +65,7 @@ typedef QVector< QVector< QVector< QgsPoint > > > QgsCoordinateSequence;
 /**
  * \ingroup core
  * \class QgsAbstractGeometry
- * \brief Abstract base class for all geometries
+ * \brief Abstract base class for all geometries.
  *
  * \note QgsAbstractGeometry objects are inherently Cartesian/planar geometries. They have no concept of geodesy, and none
  * of the methods or properties exposed from the QgsAbstractGeometry API (or QgsGeometry API) utilize
@@ -95,6 +95,12 @@ class CORE_EXPORT QgsAbstractGeometry
       sipType = sipType_QgsPolygon;
     else if ( qgsgeometry_cast<QgsCurvePolygon *>( sipCpp ) != nullptr )
       sipType = sipType_QgsCurvePolygon;
+    else if ( qgsgeometry_cast<QgsTriangulatedSurface *>( sipCpp ) != nullptr )
+      sipType = sipType_QgsTriangulatedSurface;
+    else if ( qgsgeometry_cast<QgsPolyhedralSurface *>( sipCpp ) != nullptr )
+      sipType = sipType_QgsPolyhedralSurface;
+    else if ( qgsgeometry_cast<QgsSurface *>( sipCpp ) != nullptr )
+      sipType = sipType_QgsSurface;
     else if ( qgsgeometry_cast<QgsMultiPoint *>( sipCpp ) != nullptr )
       sipType = sipType_QgsMultiPoint;
     else if ( qgsgeometry_cast<QgsMultiLineString *>( sipCpp ) != nullptr )
@@ -150,9 +156,6 @@ class CORE_EXPORT QgsAbstractGeometry
     };
     Q_ENUM( QgsAbstractGeometry::AxisOrder )
 
-    /**
-     * Constructor for QgsAbstractGeometry.
-     */
     QgsAbstractGeometry() = default;
     virtual ~QgsAbstractGeometry() = default;
     QgsAbstractGeometry( const QgsAbstractGeometry &geom );
@@ -306,7 +309,7 @@ class CORE_EXPORT QgsAbstractGeometry
     enum WkbFlag SIP_ENUM_BASETYPE( IntFlag )
     {
       FlagExportTrianglesAsPolygons = 1 << 0, //!< Triangles should be exported as polygon geometries
-      FlagExportNanAsDoubleMin = 1 << 1, //!< Use -DOUBLE_MAX to represent NaN (since QGIS 3.30)
+      FlagExportNanAsDoubleMin = 1 << 1, //!< Use -DOUBLE_MAX to represent NaN \since QGIS 3.30
     };
     Q_DECLARE_FLAGS( WkbFlags, WkbFlag )
 
@@ -644,8 +647,23 @@ class CORE_EXPORT QgsAbstractGeometry
      * \param vSpacing Vertical spacing of the grid (y axis). 0 to disable.
      * \param dSpacing Depth spacing of the grid (z axis). 0 (default) to disable.
      * \param mSpacing Custom dimension spacing of the grid (m axis). 0 (default) to disable.
+     * \param removeRedundantPoints if TRUE, then points which are redundant (e.g. they represent mid points on a straight line segment) will be skipped (since QGIS 3.38)
      */
-    virtual QgsAbstractGeometry *snappedToGrid( double hSpacing, double vSpacing, double dSpacing = 0, double mSpacing = 0 ) const = 0 SIP_FACTORY;
+    virtual QgsAbstractGeometry *snappedToGrid( double hSpacing, double vSpacing, double dSpacing = 0, double mSpacing = 0, bool removeRedundantPoints = false ) const = 0 SIP_FACTORY;
+
+    /**
+     * Simplifies the geometry by applying the Douglas Peucker simplification by distance
+     * algorithm.
+     *
+     * The caller takes ownership of the returned geometry. Curved geometries will be segmentized prior to simplification.
+     *
+     * If a simplified geometry cannot be calculated NULLPTR will be returned.
+     *
+     * The returned geometry may be invalid and contain self-intersecting rings.
+     *
+     * \since QGIS 3.38
+    */
+    virtual QgsAbstractGeometry *simplifyByDistance( double tolerance ) const = 0 SIP_FACTORY;
 
     /**
      * Removes duplicate nodes from the geometry, wherever removing the nodes does not result in a
@@ -821,7 +839,7 @@ class CORE_EXPORT QgsAbstractGeometry
 
     /**
      * \ingroup core
-     * \brief The part_iterator class provides STL-style iterator for geometry parts.
+     * \brief The part_iterator class provides an STL-style iterator for geometry parts.
      * \since QGIS 3.6
      */
     class CORE_EXPORT part_iterator
@@ -891,7 +909,7 @@ class CORE_EXPORT QgsAbstractGeometry
 
     /**
      * \ingroup core
-     * \brief The part_iterator class provides STL-style iterator for const references to geometry parts.
+     * \brief The part_iterator class provides an STL-style iterator for const references to geometry parts.
      * \since QGIS 3.6
      */
     class CORE_EXPORT const_part_iterator
@@ -951,7 +969,7 @@ class CORE_EXPORT QgsAbstractGeometry
 
     /**
      * \ingroup core
-     * \brief The vertex_iterator class provides STL-style iterator for vertices.
+     * \brief The vertex_iterator class provides an STL-style iterator for vertices.
      */
     class CORE_EXPORT vertex_iterator
     {
@@ -1172,10 +1190,16 @@ class CORE_EXPORT QgsAbstractGeometry
 
 #ifndef SIP_RUN
 
+template <class T>
+inline T qgsgeometry_cast( QgsAbstractGeometry *geom )
+{
+  return std::remove_pointer<T>::type::cast( geom );
+}
+
 template <class T>
 inline T qgsgeometry_cast( const QgsAbstractGeometry *geom )
 {
-  return const_cast<T>( std::remove_pointer<T>::type::cast( geom ) );
+  return std::remove_pointer<T>::type::cast( geom );
 }
 
 #endif
@@ -1184,12 +1208,12 @@ inline T qgsgeometry_cast( const QgsAbstractGeometry *geom )
 
 /**
  * \ingroup core
- * \brief Java-style iterator for traversal of vertices of a geometry
+ * \brief Java-style iterator for traversal of vertices of a geometry.
  */
 class CORE_EXPORT QgsVertexIterator
 {
   public:
-    //! Constructor for QgsVertexIterator
+
     QgsVertexIterator() = default;
 
     //! Constructs iterator for the given geometry
@@ -1232,13 +1256,13 @@ class CORE_EXPORT QgsVertexIterator
 
 /**
  * \ingroup core
- * \brief Java-style iterator for traversal of parts of a geometry
+ * \brief Java-style iterator for traversal of parts of a geometry.
  * \since QGIS 3.6
  */
 class CORE_EXPORT QgsGeometryPartIterator
 {
   public:
-    //! Constructor for QgsGeometryPartIterator
+
     QgsGeometryPartIterator() = default;
 
     //! Constructs iterator for the given geometry
@@ -1282,13 +1306,13 @@ class CORE_EXPORT QgsGeometryPartIterator
 
 /**
  * \ingroup core
- * \brief Java-style iterator for const traversal of parts of a geometry
+ * \brief Java-style iterator for const traversal of parts of a geometry.
  * \since QGIS 3.6
  */
 class CORE_EXPORT QgsGeometryConstPartIterator
 {
   public:
-    //! Constructor for QgsGeometryConstPartIterator
+
     QgsGeometryConstPartIterator() = default;
 
     //! Constructs iterator for the given geometry
