@@ -16,125 +16,131 @@
 #ifndef QGSCACHEDFEATUREITERATOR_H
 #define QGSCACHEDFEATUREITERATOR_H
 
+#include "qgis_core.h"
 #include "qgsfeature.h"
 #include "qgsfeatureiterator.h"
+#include "qgscoordinatetransform.h"
+#include "qgsvectorlayercache.h"
+#include <QPointer>
 
 class QgsVectorLayerCache;
 
 /**
- * @brief
- * Delivers features from the cache
- *
+ * \ingroup core
+ * \brief
+ * \brief Delivers features from the cache.
  */
 class CORE_EXPORT QgsCachedFeatureIterator : public QgsAbstractFeatureIterator
 {
   public:
-    /**
-     * This constructor creates a feature iterator, that delivers only cached information, based on the
-     * @link QgsFeatureIds @endlink. No request is made to the backend.
-     *
-     * @param vlCache          The vector layer cache to use
-     * @param featureRequest   The feature request to answer
-     * @param featureIds       The feature ids to return
-     *
-     * @deprecated Use QgsCachedFeatureIterator( QgsVectorLayerCache* vlCache, QgsFeatureRequest featureRequest )
-     *             instead
-     */
-    Q_DECL_DEPRECATED QgsCachedFeatureIterator( QgsVectorLayerCache* vlCache, const QgsFeatureRequest& featureRequest, const QgsFeatureIds& featureIds );
 
     /**
      * This constructor creates a feature iterator, that delivers all cached features. No request is made to the backend.
      *
-     * @param vlCache          The vector layer cache to use
-     * @param featureRequest   The feature request to answer
+     * \param vlCache          The vector layer cache to use
+     * \param featureRequest   The feature request to answer
      */
-    QgsCachedFeatureIterator( QgsVectorLayerCache* vlCache, const QgsFeatureRequest& featureRequest );
+    QgsCachedFeatureIterator( QgsVectorLayerCache *vlCache, const QgsFeatureRequest &featureRequest );
+
+    ~QgsCachedFeatureIterator() override;
 
     /**
      * Rewind to the beginning of the iterator
      *
-     * @return bool true if the operation was ok
+     * \returns bool TRUE if the operation was OK
      */
-    virtual bool rewind() override;
+    bool rewind() override;
 
     /**
      * Close this iterator. No further features will be available.
      *
-     * @return true if successful
+     * \returns TRUE if successful
      */
-    virtual bool close() override;
+    bool close() override;
 
     // QgsAbstractFeatureIterator interface
   protected:
+
     /**
      * Implementation for fetching a feature.
      *
-     * @param f      Will write to this feature
-     * @return bool  true if the operation was ok
-     *
-     * @see bool getFeature( QgsFeature& f )
+     * \param f      Will write to this feature
+     * \returns bool  TRUE if the operation was OK
      */
-    virtual bool fetchFeature( QgsFeature& f ) override;
+    bool fetchFeature( QgsFeature &f ) override;
 
     /**
      * We have a local special iterator for FilterFids, no need to run the generic.
      *
-     * @param f      Will write to this feature
-     * @return bool  true if the operation was ok
+     * \param f      Will write to this feature
+     * \returns bool  TRUE if the operation was OK
      */
-    virtual bool nextFeatureFilterFids( QgsFeature& f ) override { return fetchFeature( f ); }
+    bool nextFeatureFilterFids( QgsFeature &f ) override { return fetchFeature( f ); }
 
   private:
-    QgsFeatureIds mFeatureIds;
-    QgsVectorLayerCache* mVectorLayerCache;
-    QgsFeatureIds::ConstIterator mFeatureIdIterator;
+#ifdef SIP_RUN
+    QgsCachedFeatureIterator( const QgsCachedFeatureIterator &other );
+#endif
+
+    QList< QgsFeatureId > mFeatureIds;
+    QPointer< QgsVectorLayerCache > mVectorLayerCache = nullptr;
+    QList< QgsFeatureId >::ConstIterator mFeatureIdIterator;
+    QgsCoordinateTransform mTransform;
+    QgsRectangle mFilterRect;
+
+    QgsGeometry mDistanceWithinGeom;
+    std::unique_ptr< QgsGeometryEngine > mDistanceWithinEngine;
+    double mDistanceWithin = 0;
 };
 
 /**
- * @brief
- * Uses another iterator as backend and writes features to the cache
+ * \ingroup core
+ * \brief
+ * \brief Uses another iterator as backend and writes features to the cache.
  *
  */
 class CORE_EXPORT QgsCachedFeatureWriterIterator : public QgsAbstractFeatureIterator
 {
   public:
+
     /**
      * This constructor creates a feature iterator, which queries the backend and caches retrieved features.
      *
-     * @param vlCache          The vector layer cache to use
-     * @param featureRequest   The feature request to answer
+     * \param vlCache          The vector layer cache to use
+     * \param featureRequest   The feature request to answer
      */
-    QgsCachedFeatureWriterIterator( QgsVectorLayerCache* vlCache, const QgsFeatureRequest& featureRequest );
+    QgsCachedFeatureWriterIterator( QgsVectorLayerCache *vlCache, const QgsFeatureRequest &featureRequest );
 
     /**
      * Rewind to the beginning of the iterator
      *
-     * @return bool true if the operation was ok
+     * \returns bool TRUE if the operation was OK
      */
-    virtual bool rewind() override;
+    bool rewind() override;
 
     /**
      * Close this iterator. No further features will be available.
      *
-     * @return true if successful
+     * \returns TRUE if successful
      */
-    virtual bool close() override;
+    bool close() override;
 
   protected:
 
     /**
      * Implementation for fetching a feature.
      *
-     * @param f      Will write to this feature
-     * @return bool  true if the operation was ok
-     *
-     * @see bool getFeature( QgsFeature& f )
+     * \param f      Will write to this feature
+     * \returns bool  TRUE if the operation was OK
      */
-    virtual bool fetchFeature( QgsFeature& f ) override;
+    bool fetchFeature( QgsFeature &f ) override;
 
   private:
     QgsFeatureIterator mFeatIt;
-    QgsVectorLayerCache* mVectorLayerCache;
+    QPointer< QgsVectorLayerCache > mVectorLayerCache;
     QgsFeatureIds mFids;
+    QgsCoordinateTransform mTransform;
+    QgsRectangle mFilterRect;
+
 };
 #endif // QGSCACHEDFEATUREITERATOR_H
