@@ -78,7 +78,7 @@ class CORE_EXPORT QgsMeshCalcUtils
      *
      * \note this instance do not support aggregate functions
      *
-     * \deprecated QGIS 3.22 because the constructor does not specify any time interval to calculate aggregate functions
+     * \deprecated QGIS 3.22. Because the constructor does not specify any time interval to calculate aggregate functions.
      */
     Q_DECL_DEPRECATED QgsMeshCalcUtils( QgsMeshLayer *layer,
                                         const QStringList &usedGroupNames,
@@ -342,7 +342,7 @@ class CORE_EXPORT QgsMeshCalcUtils
 
     QgsMeshLayer *mMeshLayer; //!< Reference mesh
     bool mIsValid; //!< All used datasets (in datasetMap) do have outputs for same times & all used dataset names are present in mesh
-    QgsMeshDatasetGroupMetadata::DataType mOutputType; //!< Mesh can work only with one output types, so you cannot mix
+    QgsMeshDatasetGroupMetadata::DataType mOutputType = QgsMeshDatasetGroupMetadata::DataType::DataOnFaces; //!< Mesh can work only with one output types, so you cannot mix
     //!< E.g. one dataset with element outputs and one with node outputs
     QVector<double> mTimes;
     QMap < QString, std::shared_ptr<QgsMeshMemoryDatasetGroup> > mDatasetGroupMap; //!< Groups that are referenced in the expression
