@@ -51,6 +51,7 @@ class proximity(GdalAlgorithm):
     UNITS = "UNITS"
     NODATA = "NODATA"
     OPTIONS = "OPTIONS"
+    CREATION_OPTIONS = "CREATION_OPTIONS"
     EXTRA = "EXTRA"
     DATA_TYPE = "DATA_TYPE"
     OUTPUT = "OUTPUT"
@@ -156,6 +157,8 @@ class proximity(GdalAlgorithm):
         )
         self.addParameter(nodata_param)
 
+        # backwards compatibility parameter
+        # TODO QGIS 4: remove parameter and related logic
         options_param = QgsProcessingParameterString(
             self.OPTIONS,
             self.tr("Additional creation options"),
@@ -163,11 +166,26 @@ class proximity(GdalAlgorithm):
             optional=True,
         )
         options_param.setFlags(
-            options_param.flags() | QgsProcessingParameterDefinition.Flag.FlagAdvanced
+            options_param.flags() | QgsProcessingParameterDefinition.Flag.Hidden
         )
         options_param.setMetadata({"widget_wrapper": {"widget_type": "rasteroptions"}})
         self.addParameter(options_param)
 
+        creation_options_param = QgsProcessingParameterString(
+            self.CREATION_OPTIONS,
+            self.tr("Additional creation options"),
+            defaultValue="",
+            optional=True,
+        )
+        creation_options_param.setFlags(
+            creation_options_param.flags()
+            | QgsProcessingParameterDefinition.Flag.FlagAdvanced
+        )
+        creation_options_param.setMetadata(
+            {"widget_wrapper": {"widget_type": "rasteroptions"}}
+        )
+        self.addParameter(creation_options_param)
+
         extra_param = QgsProcessingParameterString(
             self.EXTRA,
             self.tr("Additional command-line parameters"),
@@ -271,6 +289,10 @@ class proximity(GdalAlgorithm):
         arguments.append("-of")
         arguments.append(output_format)
 
+        options = self.parameterAsString(parameters, self.CREATION_OPTIONS, context)
+        # handle backwards compatibility parameter OPTIONS
+        if self.OPTIONS in parameters and parameters[self.OPTIONS] not in (None, ""):
+            options = self.parameterAsString(parameters, self.OPTIONS, context)
         if options:
             arguments.extend(GdalUtils.parseCreationOptions(options))
 
