@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     Help2Html.py
@@ -17,13 +15,9 @@
 ***************************************************************************
 """
 
-__author__ = 'Victor Olaya'
-__date__ = 'August 2012'
-__copyright__ = '(C) 2012, Victor Olaya'
-
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
+__author__ = "Victor Olaya"
+__date__ = "August 2012"
+__copyright__ = "(C) 2012, Victor Olaya"
 
 import os
 import re
@@ -33,17 +27,19 @@ from qgis.PyQt.QtCore import QCoreApplication, QUrl
 
 from processing.tools import system
 
-ALG_DESC = 'ALG_DESC'
-ALG_CREATOR = 'ALG_CREATOR'
-ALG_HELP_CREATOR = 'ALG_HELP_CREATOR'
-ALG_VERSION = 'ALG_VERSION'
+ALG_DESC = "ALG_DESC"
+ALG_CREATOR = "ALG_CREATOR"
+ALG_HELP_CREATOR = "ALG_HELP_CREATOR"
+ALG_VERSION = "ALG_VERSION"
 
-exps = [(r"\*(.*?)\*", r"<i>\1</i>"),
-        ("``(.*?)``", r'<FONT FACE="courier">\1</FONT>'),
-        ("(.*?)\n==+\n+?", r'<h2>\1</h2>'),
-        ("(.*?)\n--+\n+?", r'<h3>\1</h3>'),
-        (r"::(\s*\n(\s*\n)*((\s+).*?\n)(((\4).*?\n)|(\s*\n))*)", r"<pre>\1</pre>"),
-        ("\n+", "</p><p>")]
+exps = [
+    (r"\*(.*?)\*", r"<i>\1</i>"),
+    ("``(.*?)``", r'<FONT FACE="courier">\1</FONT>'),
+    ("(.*?)\n==+\n+?", r"<h2>\1</h2>"),
+    ("(.*?)\n--+\n+?", r"<h3>\1</h3>"),
+    (r"::(\s*\n(\s*\n)*((\s+).*?\n)(((\4).*?\n)|(\s*\n))*)", r"<pre>\1</pre>"),
+    ("\n+", "</p><p>"),
+]
 
 
 def getHtmlFromRstFile(rst):
@@ -66,9 +62,9 @@ def getHtmlFromHelpFile(alg, helpFile):
             descriptions = json.load(f)
 
         content = getHtmlFromDescriptionsDict(alg, descriptions)
-        algGroup, algName = alg.id().split(':')
-        filePath = os.path.join(system.tempHelpFolder(), "{}_{}.html".format(algGroup, algName))
-        with open(filePath, 'w', encoding='utf-8') as f:
+        algGroup, algName = alg.id().split(":")
+        filePath = os.path.join(system.tempHelpFolder(), f"{algGroup}_{algName}.html")
+        with open(filePath, "w", encoding="utf-8") as f:
             f.write(content)
         return QUrl.fromLocalFile(filePath).toString()
     except:
@@ -76,21 +72,27 @@ def getHtmlFromHelpFile(alg, helpFile):
 
 
 def getHtmlFromDescriptionsDict(alg, descriptions):
-    s = tr('<html><body><h2>Algorithm description</h2>\n')
-    s += '<p>' + getDescription(ALG_DESC, descriptions) + '</p>\n'
-    s += tr('<h2>Input parameters</h2>\n')
+    s = tr("<html><body><h2>Algorithm description</h2>\n")
+    s += "<p>" + getDescription(ALG_DESC, descriptions) + "</p>\n"
+    s += tr("<h2>Input parameters</h2>\n")
     for param in alg.parameterDefinitions():
-        s += '<h3>' + param.description() + '</h3>\n'
-        s += '<p>' + getDescription(param.name(), descriptions) + '</p>\n'
-    s += tr('<h2>Outputs</h2>\n')
+        s += "<h3>" + param.description() + "</h3>\n"
+        s += "<p>" + getDescription(param.name(), descriptions) + "</p>\n"
+    s += tr("<h2>Outputs</h2>\n")
     for out in alg.outputs:
-        s += '<h3>' + out.description() + '</h3>\n'
-        s += '<p>' + getDescription(out.name(), descriptions) + '</p>\n'
-    s += '<br>'
-    s += tr('<p align="right">Algorithm author: {0}</p>').format(getDescription(ALG_CREATOR, descriptions))
-    s += tr('<p align="right">Help author: {0}</p>').format(getDescription(ALG_HELP_CREATOR, descriptions))
-    s += tr('<p align="right">Algorithm version: {0}</p>').format(getDescription(ALG_VERSION, descriptions))
-    s += '</body></html>'
+        s += "<h3>" + out.description() + "</h3>\n"
+        s += "<p>" + getDescription(out.name(), descriptions) + "</p>\n"
+    s += "<br>"
+    s += tr('<p align="right">Algorithm author: {0}</p>').format(
+        getDescription(ALG_CREATOR, descriptions)
+    )
+    s += tr('<p align="right">Help author: {0}</p>').format(
+        getDescription(ALG_HELP_CREATOR, descriptions)
+    )
+    s += tr('<p align="right">Algorithm version: {0}</p>').format(
+        getDescription(ALG_VERSION, descriptions)
+    )
+    s += "</body></html>"
     return s
 
 
@@ -98,8 +100,8 @@ def getDescription(name, descriptions):
     if name in descriptions:
         return str(descriptions[name]).replace("\n", "<br>")
     else:
-        return ''
+        return ""
 
 
 def tr(string):
-    return QCoreApplication.translate('Help2Html', string)
+    return QCoreApplication.translate("Help2Html", string)
